@@ -10,6 +10,7 @@
 #include <camel/camel.h>
 #include <camel/camel-search-private.h>
 
+#include "e-ews-common-utils.h"
 #include "common/e-ews-query-to-restriction.h"
 
 #include "camel-ews-folder.h"
@@ -189,38 +190,6 @@ ews_search_describe_criteria (const GPtrArray *words)
 	return g_string_free (desc, FALSE);
 }
 
-/* This is copy of e_str_replace_string(), to not depend on the evolution code
-   in the library code (and to not bring gtk+ into random processes). */
-static GString *
-ews_str_replace_string (const gchar *text,
-			const gchar *before,
-			const gchar *after)
-{
-	const gchar *p, *next;
-	GString *str;
-	gint find_len;
-
-	g_return_val_if_fail (text != NULL, NULL);
-	g_return_val_if_fail (before != NULL, NULL);
-	g_return_val_if_fail (*before, NULL);
-
-	find_len = strlen (before);
-	str = g_string_new ("");
-
-	p = text;
-	while (next = strstr (p, before), next) {
-		if (p < next)
-			g_string_append_len (str, p, next - p);
-
-		if (after && *after)
-			g_string_append (str, after);
-
-		p = next + find_len;
-	}
-
-	return g_string_append (str, p);
-}
-
 static CamelSExpResult *
 ews_search_process_criteria (CamelSExp *sexp,
 			     CamelFolderSearch *search,
@@ -285,7 +254,7 @@ ews_search_process_criteria (CamelSExp *sexp,
 				for (ii = 0; ii < words->len; ii++) {
 					GString *word;
 
-					word = ews_str_replace_string (g_ptr_array_index (words, ii), "\"", "\\\"");
+					word = e_ews_common_utils_str_replace_string (g_ptr_array_index (words, ii), "\"", "\\\"");
 
 					g_string_append (expression, "(body-contains \"");
 					g_string_append (expression, word->str);
