@@ -1712,7 +1712,7 @@ ecb_m365_add_recurrence (EM365Connection *cnc,
 	if (i_cal_component_count_properties (new_comp, I_CAL_RDATE_PROPERTY) > 0 ||
 	    i_cal_component_count_properties (new_comp, I_CAL_EXRULE_PROPERTY) > 0) {
 		g_propagate_error (error, EC_ERROR_EX (E_CLIENT_ERROR_NOT_SUPPORTED,
-			_("Microsoft 365 calendar cannot store component with RDATE, EXDATE or RRULE properties")));
+			_("Microsoft 365 calendar cannot store component with RDATE or EXRULE properties")));
 
 		return FALSE;
 	}
@@ -1976,7 +1976,7 @@ ecb_m365_add_reminder (EM365Connection *cnc,
 	gboolean success = TRUE;
 
 	if (i_cal_component_count_components (new_comp, I_CAL_VALARM_COMPONENT) > 1) {
-		g_propagate_error (error, ECC_ERROR_EX (E_CAL_CLIENT_ERROR_INVALID_OBJECT, _("Microsoft 365 calendar cannot store more that one event reminder")));
+		g_propagate_error (error, ECC_ERROR_EX (E_CAL_CLIENT_ERROR_INVALID_OBJECT, _("Microsoft 365 calendar cannot store more than one event reminder")));
 		return FALSE;
 	}
 
